Установка с использованием pip
==============================

    pip install m_librarian

Индикатор прогресса
===================

Чтобы позволить ``ml-import.py`` отображать индикатор выполнения, программе
требуется библиотека ``m_lib``. Вы можете установить библиотеку отдельно,
используя, например, команду ``pip install m_lib``. Или вы можете установить
библиотеку с помощью ``m_librarian``: ``pip install m_librarian[pbar]``.

Дополнительные зависимости
==========================

``pip install m_librarian[web]`` устанавливает зависимости, требующиеся
для web-интерфейса (скрипт ``ml-web.py``).

``pip install m_librarian[wx]`` устанавливает зависимости, требующиеся для
интерфейса GUI (скрипт ``ml-wx.py``, библиотека ``wxPython``). Легко
устанавливается для не-Linux платформ, но для Linux ``wxPython`` следует
устанавливать пакетным менеджером, или скачать с
https://extras.wxpython.org/wxPython4/extras/linux/gtk3/ , или использовать
``conda``::

    conda create -n wx27 python=2.7 wxpython
    conda activate wx27

Python 2.7 использован здесь только в качестве примера, библиотекарь
работает со всеми версиями Python 2.7 и 3.4_.

Установка из исходников
=======================

    python setup.py install
